#!/bin/bash
# Copyright 2010 Cloudera, inc.
set -e

usage() {
  echo "
usage: $0 <options>
  Required not-so-options:
     --cloudera-source-dir=DIR   path to cloudera distribution files
     --build-dir=DIR             path to Whirr dist.dir
     --prefix=PREFIX             path to install into

  Optional options:
     --doc-dir=DIR               path to install docs into [/usr/share/doc/whirr]
     --lib-dir=DIR               path to install Whirr home [/usr/lib/whirr]
     --installed-lib-dir=DIR     path where lib-dir will end up on target system
     --bin-dir=DIR               path to install bins [/usr/bin]
     --examples-dir=DIR          path to install examples [doc-dir/examples]
     ... [ see source for more similar options ]
  "
  exit 1
}

OPTS=$(getopt \
  -n $0 \
  -o '' \
  -l 'cloudera-source-dir:' \
  -l 'prefix:' \
  -l 'doc-dir:' \
  -l 'lib-dir:' \
  -l 'installed-lib-dir:' \
  -l 'bin-dir:' \
  -l 'examples-dir:' \
  -l 'build-dir:' -- "$@")

if [ $? != 0 ] ; then
    usage
fi

eval set -- "$OPTS"
while true ; do
    case "$1" in
        --cloudera-source-dir)
        CLOUDERA_SOURCE_DIR=$2 ; shift 2
        ;;
        --prefix)
        PREFIX=$2 ; shift 2
        ;;
        --build-dir)
        BUILD_DIR=$2 ; shift 2
        ;;
        --doc-dir)
        DOC_DIR=$2 ; shift 2
        ;;
        --lib-dir)
        LIB_DIR=$2 ; shift 2
        ;;
        --installed-lib-dir)
        INSTALLED_LIB_DIR=$2 ; shift 2
        ;;
        --bin-dir)
        BIN_DIR=$2 ; shift 2
        ;;
        --examples-dir)
        EXAMPLES_DIR=$2 ; shift 2
        ;;
        --)
        shift ; break
        ;;
        *)
        echo "Unknown option: $1"
        usage
        exit 1
        ;;
    esac
done

for var in CLOUDERA_SOURCE_DIR PREFIX BUILD_DIR ; do
  if [ -z "$(eval "echo \$$var")" ]; then
    echo Missing param: $var
    usage
  fi
done

MAN_DIR=$PREFIX/usr/share/man/man1
DOC_DIR=${DOC_DIR:-$PREFIX/usr/share/doc/whirr}
LIB_DIR=${LIB_DIR:-$PREFIX/usr/lib/whirr}
INSTALLED_LIB_DIR=${INSTALLED_LIB_DIR:-/usr/lib/whirr}
EXAMPLES_DIR=${EXAMPLES_DIR:-$DOC_DIR/examples}
BIN_DIR=${BIN_DIR:-$PREFIX/usr/bin}

# First we'll move everything into lib
install -d -m 0755 $LIB_DIR
(cd $BUILD_DIR && tar -cf - .) | (cd $LIB_DIR && tar -xf -)

# Copy in the /usr/bin/whirr wrapper
install -d -m 0755 $BIN_DIR
cat > $BIN_DIR/whirr <<EOF
#!/bin/sh

exec $INSTALLED_LIB_DIR/bin/whirr "\$@"
EOF
chmod 755 $BIN_DIR/whirr

install -d -m 0755 $MAN_DIR
gzip -c $CLOUDERA_SOURCE_DIR/whirr.1 > $MAN_DIR/whirr.1.gz

# Move the docs, but leave a symlink in place for compat. reasons
install -d -m 0755 $DOC_DIR
mv $LIB_DIR/docs/* $DOC_DIR
ln -s /${DOC_DIR/#$PREFIX/} $LIB_DIR/docs

# Fix some permissions see CDH-5086

chmod 644 $LIB_DIR/*.txt

#Remove some bits which sould not be shipped.

rm  -rf $LIB_DIR/cli/whirr.log*
rm -rf $LIB_DIR/pom.xml
rm -rf $LIB_DIR/*/pom.xml
rm -rf $LIB_DIR/*/*/pom.xml
rm -rf $LIB_DIR/*.pom
rm -rf $LIB_DIR/src/site/confluence/whirr-in-5-minutes.confluence.rej
rm -rf $LIB_DIR/services/hadoop/lib/hadoop-test-0.20.3-SNAPSHOT.jar

# Remove directories that are going elsewhere or we do not want to package e.g. cloudera
for dir in cloudera services/cassandra/src services/elasticsearch/src/main/java/ services/hadoop/src/main/java/ build-tools core/src cli/src services/cdh/src/test services/elasticsearch/src/test services/hadoop/src services/hbase/src services/voldemort/src services/zookeeper/src
do
   rm -rf $LIB_DIR/$dir
done
  
